#
# spec file for package ghc-pandoc-citeproc
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name pandoc-citeproc
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.17
Release:        bp153.1.22
Summary:        Supports using pandoc with citeproc
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-HsYAML-aeson-devel
BuildRequires:  ghc-HsYAML-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-pretty-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hs-bibutils-devel
BuildRequires:  ghc-libyaml-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-pandoc-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rfc5051-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-setenv-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-yaml-devel
%if %{with tests}
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
The pandoc-citeproc library supports automatic generation of citations and a
bibliography in pandoc documents using the Citation Style Language (CSL) macro
language. More details on CSL can be found at <http://citationstyles.org/>.

In addition to a library, the package includes an executable, pandoc-citeproc,
which works as a pandoc filter and also has a mode for converting bibliographic
databases into CSL JSON and pandoc YAML metadata formats.

pandoc-citeproc originated as a fork of Andrea Rossato's citeproc-hs.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/%{pkg_name}
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/locales
%dir %{_datadir}/%{pkg_name}-%{version}/man
%dir %{_datadir}/%{pkg_name}-%{version}/man/man1
%{_datadir}/%{pkg_name}-%{version}/LICENSE
%{_datadir}/%{pkg_name}-%{version}/README.md
%{_datadir}/%{pkg_name}-%{version}/changelog
%{_datadir}/%{pkg_name}-%{version}/chicago-author-date.csl
%{_datadir}/%{pkg_name}-%{version}/locales/*.xml
%{_datadir}/%{pkg_name}-%{version}/man/man1/pandoc-citeproc.1

%files devel -f %{name}-devel.files

%{_mandir}/man1/pandoc-citeproc.1%{?ext_man}

%changelog
* Thu Feb 27 2020 psimons@suse.com
- Update pandoc-citeproc to version 0.17.
  pandoc-citeproc (0.17)
  * Only print labels if selected variable is non-empty (#437).
  * Make reference-section-title work even when doc ends with header (#431).
    Previously, setting `reference-section-title` wouldn't do anything
    when the document ended with a header -- contrary to what the
    documentation suggests.
  * Use Text instead of String (#430, Albert Krewinkel).
* Mon Dec 23 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.4.1.
  pandoc-citeproc (0.16.4.1)
  * Allow pandoc 2.9.
  pandoc-citeproc (0.16.4)
  * Simplify compat since we now require pandoc >= 2.8.
  * Update man page.  Clarify that `reference-section-title` doesn't have any
    effect when an explicit Div is used (#424).
  * Qualify fail with Prelude to fix compiler warnings.
  * Disable `raw_attribute` extension when writing Markdown.
    This way we avoid e.g. `<i>{=html}` in the CSL export.
  * Use pandoc-types 1.20.  Note that this change removes
    the ability to compile pandoc-citeproc with
    older versions of pandoc (< 2.8).
  * Incorporate the switch to Text in the dependencies (Christian
    Despres).  The changes to the structure of the code are fairly minimal.
    None of the types have changed, requiring a reasonable amount of
    packing, unpacking, and view patterns.
  pandoc-citeproc (0.16.3.1)
  * Fix how LANG is set for bibtex conversion.
    We were using a `-` where `_` is standard.
  * Make locale retrieval more robust (#420).
    Previously an error was raised if the locale was 'C'.
    Now 'C' is treated as default (en-US locale is used).
  pandoc-citeproc (0.16.3)
  * Set `hanging-indent` class on `refs` Div if specified by the style (#410).
    This depends on whether the `hanging-indent` attribute of
    `<bibliography>` is true.
  * Update chicago-author-date.csl and locales.
  * Add new biblatex @dataset entry type (#413).
  * Cleanup cabal file and remove old ghc 6.10 conditional.
  * Replace some of the yaml use with HsYAML-aeson (vijayphoenix).
  * Allow xml-conduit 1.9.
  * Allow network 3.1.
  * Allow pandoc 2.8.
  * Use pandoc-types 1.17.6.1
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Sat Apr 20 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.2.
  pandoc-citeproc (0.16.2)
  * Normalize for sorting by padding numerical strings with 0s (#399).
    This is a somewhat ugly fix to #399, and might be wrong
    if there are strings that may be numerical and should not
    be sorted in numerical order.  But this is the best we can
    do right now without major archictectural changes.
  * Add Ord instance for CNum.  [Minor API change.]
  * Allow empty sort-separator.
    Previously this was overridden with the default.
    Text.CSL.Common: export getOptionValWithDefault [API change].
  * Fix omitted phrase in --man documentation (#394, Daniel Himmelstein).
  * Amend fix to #392 (#393).  Initials were being dropped when there were
    more than two unspaced initials.
* Thu Mar 14 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.1.3.
  pandoc-citeproc (0.16.1.3)
  * Correctly handle initials even when
    presented without a space, as in "J.G. Smith" (#392).
  * Avoid generating Str "" when possible.
  * Allow superscript in-text styles to be treated as "notes"
    for purposes of moving punctuation (George Pollard, #382).
* Sat Mar  9 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.1.2.
  pandoc-citeproc (0.16.1.2)
  * Fix extraction page-first when page is not fully numeric (#386).
  * For cites in notes in a footnote style, don't add comma right after
    open parentheses.  Partially addresses #389.
  * Ensure that URIs (e.g. in DOIs) are properly escaped (#391).
* Sun Mar  3 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.1.1.
  pandoc-citeproc (0.16.1.1)
  * Bump version bounds for pandoc, network.
* Mon Feb 18 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.1.
  pandoc-citeproc (0.16.1)
  * Add --columns option.  This allows users to specify the column
    width for text wrapping in --bib2yaml output.
  * Use --columns=0 in biblio2yaml tests to avoid problems with
    different wrapping in different libyaml versions.
  * man page: remove references to obsolete pandoc_markdown(5) man page.
  * man page: add info on how to set metadata (#378).
* Fri Feb  8 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.0.2.
  pandoc-citeproc (0.16.0.2)
  * Remove need for HTTP access in test for #213.
* Thu Feb  7 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.0.1.
  pandoc-citeproc (0.16.0.1)
  * Fix regression on #213.  Literals without special handling
    (such as call-number, dimensions, scale, language) were being
    dropped.  Added regression test.
* Thu Jan 31 2019 psimons@suse.com
- Update pandoc-citeproc to version 0.16.
  pandoc-citeproc (0.16)
  * Detect en dash in page range (Andrew Dunning).  Ensure that `--` or `–`
    are detected as page ranges. This fixes a regression that caused the
    second half of the range to be appended to a URL in note styles.
  * Fix collapsing behavior with items with status but no year (#371).
  * Style: Add OStatus constructor to Output [API change].
  * Allow pandoc 2.6.
  * Added pandoc-citeproc to build-tools for test suite (#369).
* Sat Dec 22 2018 ptrommler@icloud.com
- Add _constraints file to fix build on powerpc64le
  * need almost 5 GB disk space
* Sun Dec 16 2018 psimons@suse.com
- Add pandoc-citeproc at version 0.15.0.1.
